@@ -60,6 +60,8 @@ INDEX_HTML = os.path.join(STATIC_ROOT, 'index.html')
 def remove_file(filename):
     try:
         os.remove(filename)
+    except PermissionError:
+        pass
     except OSError as e:  # this would be "except OSError, e:" before Python 2.6
         if e.errno != errno.ENOENT:  # errno.ENOENT = no such file or directory
             raise  # re-raise exception if a different error occurred
@@ -265,8 +267,6 @@ def hanlp_jar_path(version):
 
 
 def uninstall_hanlp_jar(version='old'):
-    import jpype
-    jpype.shutdownJVM()
     if version == 'old':
         vs = hanlp_installed_jar_versions()
         if len(vs) > 1:
